;**********************************************************
;* NCL script for testing the output of the FTJ16 compset *
;* 						          *
;* Read in 30 day average output (default) and plotting...*
;* Zonal mean zonal wind                                  *
;* Zonal mean temperature                                 *
;* Zonal mean precipitation                               *
;*                                                        *
;* all averaged over days 210 to 1200 of the integration  *
;*                                                        *
;* Replace the cdf_path below to point toward the         *
;* directory containing the FTJ16 output                  *
;*                                                        *
;* Isla Simpson 06 02 19                                  *
;**********************************************************


;****************lat-pre plotting procedure
procedure contour_zm_linearp(wks,data[*][*]:numeric,ci[1]:numeric, \
cmin[1]:numeric,cmax[1]:numeric,plots[*]:graphic, \
iplot[1]:numeric)

begin
;set up contour levels
 ncontours=toint((cmax-cmin)/ci)+1
 levels=ispan(0,ncontours-1,1)
 flevels=tofloat(levels)
 flevels=cmin + flevels*ci

;place line at every second contour, exclude zero
 lconts=new(ncontours,string)
 lconts(:)="NoLine"
 izero=ncontours/2
 lconts(izero::2)="LineandLabel"
 lconts(izero:0:-2)="LineandLabel"

;define colour map
 gsn_define_colormap(wks,"BlueWhiteOrangeRed")

;set up plotting resources
 res     = True
 res@gsnDraw = False ; do not draw until the end
 res@gsnFrame = False ; do not automatically advance 'frame'

 res@trYReverse  = True ; reverse Y axis

 res@cnFillOn = True ; color fill

 res@cnLevelSelectionMode = "ExplicitLevels"
 res@cnLevels = flevels
 ; contour every second line
 res@cnMonoLevelFlag=False
 res@cnLevelFlags = lconts
 res@gsnContourZeroLineThicknessF=0. ;don't plot zero line
 res@gsnContourNegLineDashPattern = 2
 res@cnLineThicknessF=2.

 ;contour labelling
 res@cnLineLabelsOn = True
 res@cnExplicitLineLabelsOn=False

 res@gsnYAxisIrregular2Linear = True

;controlling label bar
  res@lbLabelAutoStride   = True         ; Clean up labelbar labels.
  res@lbBoxLinesOn        = True         ; labelbar box lines.
  res@lbTitlePosition     = "Bottom"
  res@lbTitleFontHeightF = 0.02
  res@lbLabelFontHeightF = 0.015
  res@pmLabelBarHeightF = 0.1
  res@lbBoxMinorExtentF = 0.2
  res@lbBoxSeparatorLinesOn=False

  plots(iplot)=gsn_csm_contour(wks,data,res)
  return(plots)
end
;*************end lat-pre plotting procedure

;************lat line plot plotting procedure
procedure plot_lat_line(wks,data[*]:numeric,xval[*]:numeric,plots[*]:graphic, \
iplot[1]:numeric)

begin
  res2  = True

  res2@gsnDraw=False ; do not draw until the end
  res2@gsnFrame=False ; do not automatically advance 'frame'
  res2@tiMainString = "Testing"
  res2@trXMaxF = 90
  res2@tiMainString = "Precipitation"
  res2@tiMainFontHeightF = 0.021
  res2@tiXAxisString = "Latitude"
  res2@tiXAxisFontHeightF = 0.018
  res2@tiYAxisString = "Precipitation (mm/day)"
  res2@tiYAxisFontHeightF = 0.018
  res2@xyLineThicknesses = (/2.0/)

  plots(iplot)=gsn_csm_xy(wks,xval,data,res2)
  return(plots)
end

;************end lat line plot plotting procedure


;*************MAIN PROGRAM STARTS HERE
begin

  ; !!!modify this paths to point toward your model output
  cdf_path="/scratch/cluster/islas/archive/FTJ16_f19_f19.001/atm/hist/"

  ; opening up all 30 day average history files (assuming default history settings have been retained)
  ncfiles=systemfunc("ls "+cdf_path+"*h0*.nc")

  nfiles=dimsizes(ncfiles)
  in=addfiles(ncfiles,"r")

  timetotal=in[:]->time
  lon=in[0]->lon
  lat=in[0]->lat
  lev=in[0]->lev

  ; only reading indices 7 to 40 i.e., the 30 day average starting in day 210 to that ending at day 1200
  u=in[:]->U(7:40,:,:,:)
  t=in[:]->T(7:40,:,:,:)
  precl=in[:]->PRECL(7:40,:,:)
  time=in[:]->time(7:40)

  ; calculate zonal means and time means
  uzm=dim_avg_n_Wrap(u,3)
  tzm=dim_avg_n_Wrap(t,3)
  preclzm=dim_avg_n_Wrap(precl,2)
  uzmtm=dim_avg_n_Wrap(uzm,0)
  tzmtm=dim_avg_n_Wrap(tzm,0)
  preclzmtm=dim_avg_n_Wrap(preclzm,0)
  preclzmtm(:)=preclzmtm(:)*86400.*1000.

  ;set units and long name for plotting purposes
  uzmtm@long_name="Zonal mean zonal wind"
  uzmtm@units="m/s"

  tzmtm@long_name="Zonal mean temperature"
  tzmtm@units="K"

  preclzmtm@long_name="Zonal mean precipitation"
  preclzmtm@units="mm/day"

  ;open up workspace
  wks=gsn_open_wks("ps","FTJ16_test")

  ;plot the plots
  plots=new(6,graphic)
  contour_zm_linearp(wks,uzmtm,2,-60,60,plots,0)
  contour_zm_linearp(wks,tzmtm,10,180,300,plots,1)
  plot_lat_line(wks,preclzmtm,lat,plots,2)

  resp=False
  gsn_panel(wks,plots,(/2,3/),resp)

end 






































